@@ -22,8 +22,12 @@ Help Functions
 import bz2, collections, itertools, math, random, os.path, time
 import cPickle as pickle
 
-import scipy.stats
 import numpy as np
+try:
+    # needed just for spearman's rank distance.
+    import scipy.stats
+except:
+    pass
 
 import Orange.orng.orngVizRank as vr
 
